==> pypl-bt-1.8.0.0.zip: docs_release/HYBRIS_BRAINTREE_INSTALLATION.md <==
Hybris with PayPal cartridge, Windows/Linux step-by-step installation. You can skip 1-3 steps, if you have installed hybris accelerator

1) Unzip Hybris sources
2) Install recipe from $HYBRIS_DIR/installer
    recipes: 
	2005, 2011, 2105, 2205	--> cx

    ./install.sh -r <needed-recipe> -A local_property:initialpassword.admin=nimda    ```
3) cd $HYBRIS_DIR/hybris/bin/platform
    ```echo develop | ant createConfig    ```
4) Unzip cartridge zip, copy extensions from /extensions to $HYBRIS_DIR/hybris/bin/custom-paypal-bt, copy properties from /samples/local.properties to your $HYBRIS_DIR/hybris/config/ local.properties file.
5) Add next extensions to $HYBRIS_DIR/hybris/config/local-extensions.xml 
	Core-extensions.
    <extension name="braintree"/>
    <extension name="braintreeacceleratorfacades"/>
    <extension name="braintreefacades"/>
    <extension name="braintreeb2bfacades"/>
    <extension name="braintreefulfilmentprocess"/>
    <extension name="braintreecustomersupportbackoffice"/>
    <extension name="braintreehac"/>
	B2C related extensions. Add If you use B2C accelerator
    <extension name="braintreeaddon"/>
    <extension name="braintreewebservice"/>
	B2B related extensions. Add If you use B2B accelerator
    <extension name="braintreeb2baddon"/>
    <extension name="braintreeb2bwebservice"/>
	Spartacus related extensions. Add If you use Spartacus storefront.
    <extension name="braintreespartacusdata"/>
    <extension name='spartacussampledata' />
    B2C related extensions.
    <extension name="braintreeoccaddon"/>
    B2B related extensions.
    <extension name="braintreeb2boccaddon"/>
6) cd $HYBRIS_DIR/hybris/bin/platform. Installing addons which were added on the fourth step.

•	B2C. If you add braintreeaddon on the previous step
ant addoninstall -Daddonnames="braintreeaddon" -DaddonStorefront.yacceleratorstorefront="yacceleratorstorefront"

•	B2B. If you add braintreeb2baddon on the previous step
ant addoninstall -Daddonnames="braintreeb2baddon" -DaddonStorefront.yacceleratorstorefront="yb2bacceleratorstorefront"

•	Spartacus B2C. If you add braintreeoccaddon on the previous step
ant addoninstall -Daddonnames="braintreeoccaddon" -DaddonStorefront.ycommercewebservices="ycommercewebservices"

•	Spartacus B2B. If you add braintreeb2boccaddon on the previous step
ant addoninstall -Daddonnames="braintreeb2boccaddon" -DaddonStorefront.ycommercewebservices="ycommercewebservices"


6) cd $HYBRIS_DIR/hybris/bin/platform
	ant clean all initialize
	./hybrisserver.sh

==> pypl-bt_1.10.0.0.zip: docs_release/HYBRIS_BRAINTREE_INSTALLATION.md <==
Hybris with PayPal cartridge, Windows/Linux step-by-step installation. You can skip 1-3 steps, if you have installed hybris accelerator

1) Unzip Hybris sources
2) Install recipe from $HYBRIS_DIR/installer
    recipes: 
	2011, 2105, 2205, 2211	--> cx

    ./install.sh -r <needed-recipe> -A local_property:initialpassword.admin=nimda    ```
3) cd $HYBRIS_DIR/hybris/bin/platform
    ```echo develop | ant createConfig    ```
4) Unzip cartridge zip, copy extensions from /extensions to $HYBRIS_DIR/hybris/bin/custom-paypal-bt, copy properties from /samples/local.properties to your $HYBRIS_DIR/hybris/config/ local.properties file.
5) Add next extensions to $HYBRIS_DIR/hybris/config/local-extensions.xml 
	Core-extensions.
    <extension name="braintree"/>
    <extension name="braintreeacceleratorfacades"/>
    <extension name="braintreefacades"/>
    <extension name="braintreeb2bfacades"/>
    <extension name="braintreefulfilmentprocess"/>
    <extension name="braintreecustomersupportbackoffice"/>
    <extension name="braintreehac"/>
	B2C related extensions. Add If you use B2C accelerator
    <extension name="braintreeaddon"/>
    <extension name="braintreewebservice"/>
	B2B related extensions. Add If you use B2B accelerator
    <extension name="braintreeb2baddon"/>
    <extension name="braintreeb2bwebservice"/>
    Addon for connect with PayPal which works on SAP commerce cloud 2011-2105.
    <extension name="braintreeb2bregistrationaddon"/>
    Addon for connect with PayPal which works on SAP commerce cloud 2205.
    <extension name="braintreeb2bregistration2205addon"/>
	Spartacus related extensions. Add If you use Spartacus storefront.
    <extension name="braintreespartacusdata"/>
    <extension name='spartacussampledata' />
    B2C related extensions.
    <extension name="braintreeoccaddon"/>
    B2B related extensions.
    <extension name="braintreeb2boccaddon"/>
6) cd $HYBRIS_DIR/hybris/bin/platform. Installing addons which were added on the fourth step.

•	B2C. If you add braintreeaddon on the previous step
ant addoninstall -Daddonnames="braintreeaddon" -DaddonStorefront.yacceleratorstorefront="yacceleratorstorefront"

•	B2B(2011-2105 Hybris version). If you add braintreeb2baddon on the previous step
ant addoninstall -Daddonnames="braintreeb2baddon" -DaddonStorefront.yacceleratorstorefront="yb2bacceleratorstorefront"
ant addoninstall -Daddonnames="braintreeb2bregistrationaddon" -DaddonStorefront.yacceleratorstorefront="yb2bacceleratorstorefront"

•	B2B(2205 Hybris version). If you add braintreeb2baddon on the previous step
ant addoninstall -Daddonnames="braintreeb2baddon" -DaddonStorefront.yacceleratorstorefront="yb2bacceleratorstorefront"
ant addoninstall -Daddonnames="braintreeb2bregistration2205addon" -DaddonStorefront.yacceleratorstorefront="yb2bacceleratorstorefront"

•	B2B(2211 Hybris version). If you add braintreeb2baddon on the previous step
ant addoninstall -Daddonnames="braintreeb2baddon" -DaddonStorefront.yacceleratorstorefront="yb2bacceleratorstorefront"

•	Spartacus B2C. If you add braintreeoccaddon on the previous step
ant addoninstall -Daddonnames="braintreeoccaddon" -DaddonStorefront.ycommercewebservices="ycommercewebservices"

•	Spartacus B2B. If you add braintreeb2boccaddon on the previous step
ant addoninstall -Daddonnames="braintreeb2boccaddon" -DaddonStorefront.ycommercewebservices="ycommercewebservices"


6) cd $HYBRIS_DIR/hybris/bin/platform
	ant clean all initialize
	./hybrisserver.sh
